#!/bin/sh
echo 'name: safe
version: 0.3.3
id: safe-0.3.3-3fc1838ea15326253992757aa508c0f2

license: BSD3
copyright: Neil Mitchell 2007-2011
maintainer: Neil Mitchell <ndmitchell@gmail.com>
stability:
homepage: http://community.haskell.org/~ndm/safe/
package-url:
synopsis: Library for safe (pattern match free) functions
description: Partial functions from the base library, such as @head@ and @!!@, modified
             to return more descriptive error messages, programmer defined error messages,
             @Maybe@ wrapped results and default values.
             These functions can be used to reduce the number of unsafe pattern matches in
             your code.
category: Unclassified
author: Neil Mitchell <ndmitchell@gmail.com>
pkgpath: devel/hs-safe
exposed: True
exposed-modules: Safe Safe.Foldable
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/safe-0.3.3
library-dirs: /usr/local/lib/ghc/safe-0.3.3
hs-libraries: HSsafe-0.3.3
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-safe-0.3.3/html/safe.haddock
haddock-html: /usr/local/share/doc/hs-safe-0.3.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
